MCD triple_111
Projet ( projet, libellé )

- Le champ projet constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Projet.
- Le champ libellé était déjà un simple attribut de l'entité Projet.

Technicien ( technicien, nom technicien )

- Le champ technicien constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Technicien.
- Le champ nom technicien était déjà un simple attribut de l'entité Technicien.

Utiliser ( carnet u1, #projet u2, #technicien u1 u2 )

- Le champ carnet fait partie de la clé primaire de la table. Sa table d'origine (Carnet) ayant été supprimée, il n'est pas considéré comme clé étrangère. Il obéit par contre à la contrainte d'unicité 1.
- Le champ projet fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité Projet. Il obéit en outre à la contrainte d'unicité 2.
- Le champ technicien est une clé étrangère. Il a migré directement à partir de l'entité Technicien en perdant son caractère identifiant. Il obéit en outre aux contraintes d'unicité 1 et 2.

NB. La table Carnet a été supprimée car elle était réduite à la clé primaire de son entité d'origine. Pour conserver de telles tables, préfixez d'un « + » la définition des entités d'origine.